DeviceConfig

Struct DeviceConfig 

pub struct DeviceConfig { /* private fields */ }
Describes a required set of devices for find_device_files.

Examples

use furiosa_device::DeviceConfig;

// 1 core
DeviceConfig::warboy().build();

// 1 core x 2
DeviceConfig::warboy().count(2);

// Fused 2 cores x 2
DeviceConfig::warboy().fused().count(2);

Textual Representation

DeviceConfig supports textual representation, which is its equivalent string representation. One can obtain the corresponding DeviceConfig from the textual representation by using the FromStr trait, or by calling from_env after setting an environment variable.

use std::str::FromStr;

use furiosa_device::DeviceConfig;

let config = DeviceConfig::from_env("SOME_OTHER_ENV_KEY").build();
let config = DeviceConfig::from_str("npu:0:0,npu:0:1").unwrap(); // get config directly from a string literal

The rules for textual representation are as follows:

use std::str::FromStr;

use furiosa_device::DeviceConfig;

// Using specific device names
DeviceConfig::from_str("npu:0:0").unwrap(); // npu0pe0
DeviceConfig::from_str("npu:0:0-1").unwrap(); // npu0pe0-1

// Using device configs
DeviceConfig::from_str("warboy*2").unwrap(); // single pe x 2 (equivalent to "warboy(1)*2")
DeviceConfig::from_str("warboy(1)*2").unwrap(); // single pe x 2
DeviceConfig::from_str("warboy(2)*2").unwrap(); // 2-pe fusioned x 2

// Combine multiple representations separated by commas
DeviceConfig::from_str("npu:0:0-1,npu:1:0-1").unwrap(); // npu0pe0-1, npu1pe0-1

Implementations

Source

impl DeviceConfig

pub fn warboy() -> DeviceConfigBuilder<Arch, NotDetermined, NotDetermined>

Returns a builder associated with Warboy NPUs.

pub fn warboy_a0() -> DeviceConfigBuilder<Arch, NotDetermined, NotDetermined>

pub fn from_env<K: ToString>(key: K) -> EnvBuilder<NotDetermined>

Returns a builder struct to read config saved in an environment variable. You can provide fallback options to the builder in case the envrionment variable is empty.