pub struct DeviceFile { /* private fields */ }Expand description
An abstraction for a device file and its mode.
Implementations
Sourceimpl DeviceFile
impl DeviceFile
Sourcepub fn device_index(&self) -> u8
pub fn device_index(&self) -> u8
Returns the device index (e.g., 1 for npu1pe0).
Sourcepub fn core_range(&self) -> CoreRange
pub fn core_range(&self) -> CoreRange
Returns the range of cores this device file may occupy.
Sourcepub fn mode(&self) -> DeviceMode
pub fn mode(&self) -> DeviceMode
Return the mode of this device file.